@@ -1,7 +1,6 @@
 /***************************************************************************
                           kdesupport.cpp  -  description
                              -------------------
-    begin                : Mon Feb 5 2001
     copyright            : (C) 2001 by Richard Dale
     email                : Lost_Highway@tipitina.demon.co.uk
  ***************************************************************************/
@@ -9,7 +8,7 @@
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
+ *   it under the terms of the GNU Library General Public License as published by*
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
@@ -503,3 +502,30 @@ KDESupport::arrayWithMediaList(JNIEnv * env, DOM::MediaList * mediaList)
 	return (jobject) objectArray;
 }
 
+QCStringList *
+KDESupport::toQCStringList(JNIEnv * env, jobjectArray stringList, QCStringList ** qstringList)
+{
+	int				length;
+	int				index;
+	jstring			jstr;
+	static QCString * _qstring_temp = 0;
+
+	if (*qstringList == 0) {
+		*qstringList = new QCStringList();
+	}
+
+	(*qstringList)->clear();
+
+	if (stringList == 0) {
+		return *qstringList;
+	}
+
+	length = env->GetArrayLength(stringList);
+	for (index = 0; index < length; index++) {
+		jstr = (jstring) env->GetObjectArrayElement(stringList, index);
+		(*qstringList)->append((QCString &) * (QCString *) QtSupport::toQCString(env, jstr, &_qstring_temp));
+		env->DeleteLocalRef(jstr);
+	}
+
+	return *qstringList;
+}
