@@ -15,14 +15,15 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  */
 
 #ifndef KJSEMBED_PAINTER_IMP_H
 #define KJSEMBED_PAINTER_IMP_H
 
-#include <kjsembed/jsobjectproxy_imp.h>
+#include <kjsembed/jsbindingbase.h>
+#include <kjsembed/jsproxy_imp.h>
 #include <qpen.h>
 #include <qpainter.h>
 
@@ -31,19 +32,32 @@ class QPixmap;
 namespace KJSEmbed {
 namespace Bindings {
 
+    class PainterLoader : public JSBindingBase
+    {
+        public:
+            KJS::Object createBinding(KJSEmbedPart *jspart, KJS::ExecState *exec, const KJS::List &args) const;
+            void addBindings( KJSEmbedPart *jspart, KJS::ExecState *exec, KJS::Object &proxy) const;
+    };
+
+    
 class PainterRef
 {
 	public:
 		PainterRef();
 		~PainterRef();
-		
+
 		QPainter *painter();
-		
+
 		QPaintDevice *device();
 		void setDevice(QPaintDevice *d);
+
+    void setCanDelete(bool can ) {m_canDelete = can;}
+    bool canDelete() const { return m_canDelete;}
+    
 	private:
 		QPainter *m_painter;
 		QPaintDevice *m_device;
+    bool m_canDelete;
 };
 
 /**
@@ -54,19 +68,12 @@ class PainterRef
 
 class Painter : public JSProxyImp
 {
-/*    Q   _OBJECT
-    Q_PROPERTY( QPixmap pixmap READ pixmap WRITE setPixmap )
-    Q_PROPERTY( QPen pen READ pen WRITE setPen )
-    Q_PROPERTY( QFont font READ font WRITE setFont )
-    Q_PROPERTY( QColor brush READ brush WRITE setBrush )
-
-*/
 	/** Identifiers for the methods provided by this class. */
-	enum MethodId {Methodbegin, Methodend, Methodpixmap, MethodsetPixmap, MethodsetPen, Methodpen, MethodtextBox, MethodmoveTo, MethodlineTo, MethoddrawPoint,  MethoddrawLine, MethoddrawRect,  MethoddrawRoundRect, MethoddrawEllipse, MethoddrawText, MethoddrawArc, MethoddrawPie, MethoddrawPixmap, MethoddrawImage, MethoddrawTiledPixmap, Methodscale, Methodshear, Methodrotate, Methodtranslate, MethodsetFont, Methodfont, MethodsetBrush, Methodbrush, MethodbackgroundColor, MethodsetBackgroundColor};    
+	enum MethodId {Methodbegin, Methodend, Methodpixmap, MethodsetPixmap, MethodsetPen, Methodpen, MethodtextBox, MethodmoveTo, MethodlineTo, MethoddrawPoint,  MethoddrawLine, MethoddrawRect,  MethoddrawRoundRect, MethoddrawEllipse, MethoddrawText, MethoddrawArc, MethoddrawPie, MethoddrawPixmap, MethoddrawImage, MethoddrawTiledPixmap, Methodscale, Methodshear, Methodrotate, Methodtranslate, MethodsetFont, Methodfont, MethodsetBrush, Methodbrush, MethodbackgroundColor, MethodsetBackgroundColor};
 public:
     Painter( KJS::ExecState *exec, int id );
     virtual ~Painter();
-    
+
     static void addBindings( KJS::ExecState *exec, KJS::Object &object );
 
     /** Returns true iff this object implements the call function. */
@@ -76,10 +83,10 @@ public:
     virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
 private:
 
+    bool begin();
     bool begin(QPaintDevice *dev);
     bool end();
     QPixmap pixmap() const;
-//    void setPixmap( const QPixmap &pix );
     void setPen( const QPen& pn);
     QPen pen() const;
     QRect textBox(const QString &text);
@@ -110,7 +117,7 @@ private:
 private:
     int mid;
     PainterRef *pr;  // temps now
-    
+
 };
 
 } // namespace Bindings
