@@ -15,14 +15,15 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  */
 
 #ifndef KJSEMBEDJSPROXYIMP_H
 #define KJSEMBEDJSPROXYIMP_H
 
 #include <kjs/function.h>
+#include <kjsembed/global.h>
 
 namespace KJSEmbed {
 
@@ -31,7 +32,7 @@ namespace KJSEmbed {
  *
  * @author Richard Moore, rich@kde.org
  */
-class JSProxyImp :  public KJS::InternalFunctionImp
+class KJSEMBED_EXPORT JSProxyImp :  public KJS::InternalFunctionImp
 {
 public:
     /** Creates the function using the builtin function prototype of the interpreter. */
