@@ -367,7 +367,7 @@ KJS::Value QCanvasSpriteImp::setFrame_6( KJS::ExecState *exec, KJS::Object &obj,
 KJS::Value QCanvasSpriteImp::setFrameAnimation_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
 
-    QCanvasSprite::FrameAnimationType arg0; // TODO (hack for QCanvasSprite)
+    QCanvasSprite::FrameAnimationType arg0 = QCanvasSprite::Cycle; // TODO (hack for QCanvasSprite)
 
     int arg1 = extractInt(exec, args, 1);
 
