@@ -13,8 +13,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef _KACCELBASE_H
@@ -27,7 +27,7 @@
 #include <qvaluelist.h>
 
 #include "kaccelaction.h"
-#include "kkeyserver_x11.h"
+#include "kkeyserver.h"
 
 class QPopupMenu;
 class QWidget;
@@ -116,10 +116,9 @@ class QWidget;
  * menu structure.
  *
  * @short Configurable key binding support.
- * @version $Id: kaccelbase.h 322023 2004-06-19 20:33:37Z sedwards $
  */
 
-class KAccelBase
+class KDECORE_EXPORT KAccelBase
 {
  public:
 	enum Init { QT_KEYS = 0x00, NATIVE_KEYS = 0x01 };
