@@ -527,7 +527,7 @@ void Uic::createPopupMenuImpl( const QDomElement &e, const QString &parentClass,
 {
     int i = 0;
     for ( QDomElement n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
-	if ( n.tagName() == "action" ) {
+	if ( n.tagName() == "action" || n.tagName() == "actiongroup" ) {
 	    QDomElement n2 = n.nextSibling().toElement();
 	    if ( n2.tagName() == "item" ) { // the action has a sub menu
 		QString itemName = "self." + n2.attribute( "name" );
