@@ -1,7 +1,7 @@
 /*
  * The main module for SIP.
  *
- * Copyright (c) 2004
+ * Copyright (c) 2005
  * 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
  * 
  * This file is part of SIP.
@@ -27,7 +27,7 @@
 #define	PACKAGE	"sip"
 #endif
 
-#define	VERSION	"4.1.1 (4.1.1-255)"
+#define	VERSION	"4.2.1 (4.2.1-297)"
 
 
 /* Global variables - see sip.h for their meaning. */
@@ -178,6 +178,9 @@ int main(int argc,char **argv)
 		filename = "stdin";
 	}
 
+	if (releaseGIL && warnings)
+		warning("The -g command line flag is deprecated\n");
+
 	/* Parse the input file. */
 	parse(&spec,file,filename,versions,xfeatures);
 
@@ -436,7 +439,7 @@ static void help(void)
 {
 	printf(
 "Usage:\n"
-"    %s [-h] [-V] [-a file] [-c dir] [-d file] [-e] [-g] [-I dir] [-j #] [-m file] [-r] [-s suffix] [-t version] [-w] [-x feature] [-z file] [file]\n"
+"    %s [-h] [-V] [-a file] [-c dir] [-d file] [-e] [-I dir] [-j #] [-m file] [-r] [-s suffix] [-t version] [-w] [-x feature] [-z file] [file]\n"
 "where:\n"
 "    -h          display this help message\n"
 "    -V          display the %s version number\n"
@@ -445,7 +448,6 @@ static void help(void)
 "    -c dir      the name of the code directory [default not generated]\n"
 "    -d file     the name of the documentation file [default not generated]\n"
 "    -e          enable support for exceptions [default disabled]\n"
-"    -g          always release the GIL (SIP v3.x behaviour)\n"
 "    -I dir      look in this directory when including files\n"
 "    -j #        split the generated code into # files [default 1 per class]\n"
 "    -r          generate code with tracing enabled [default disabled]\n"
