@@ -65,7 +65,7 @@ public class ScribbleWindow extends QWidget {
 			_buffer.fill( white() );
 			
 			// and copy it over to the window
-			QPaintDevice.bitBlt( this, 0, 0, _buffer );
+			bitBlt( this, 0, 0, _buffer );
 		}
 		
 		
@@ -147,7 +147,7 @@ public class ScribbleWindow extends QWidget {
 		  * painting, for example when it has been obscured and then revealed again.
 		  */
 		protected void paintEvent(QPaintEvent event) {
-			QPaintDevice.bitBlt(this, 0, 0, _buffer);
+			bitBlt(this, 0, 0, _buffer);
 		}
 	
 		/**
@@ -158,7 +158,7 @@ public class ScribbleWindow extends QWidget {
 			QPixmap save = new QPixmap( _buffer );
 			_buffer.resize( event.size() );
 			_buffer.fill( white() );
-			QPaintDevice.bitBlt( _buffer, 0, 0, save );
+			bitBlt( _buffer, 0, 0, save );
 		}
 	}
 	
