@@ -889,7 +889,6 @@ set_obj_info(const char * className, smokeruby_object * o)
 		if (classId == 0) {
 			VALUE new_klass = Qnil;
 			QString className(meta->className());
-
 			// The konsolePart class is in kdebase, and so it can't be in the Smoke library.
 			// This hack instantiates a Ruby KDE::KonsolePart instance
 			if (className == "konsolePart") {
@@ -1663,25 +1662,6 @@ new_qt(int argc, VALUE * argv, VALUE klass)
     return result;
 }
 
-static VALUE qt_invoke(int argc, VALUE * argv, VALUE self);
-static VALUE qt_signal(int argc, VALUE * argv, VALUE self);
-
-VALUE
-new_qobject(int argc, VALUE * argv, VALUE klass)
-{
-	// TODO: Don't do this everytime a new instance is created, just once..
-	rb_define_method(klass, "qt_invoke", (VALUE (*) (...)) qt_invoke, -1);
-	rb_define_method(klass, "qt_emit", (VALUE (*) (...)) qt_invoke, -1);
-	rb_define_method(klass, "metaObject", (VALUE (*) (...)) metaObject, 0);
-	VALUE signalNames = rb_funcall(qt_internal_module, rb_intern("getSignalNames"), 1, klass);
-	for (long index = 0; index < RARRAY(signalNames)->len; index++) {
-	    VALUE signal = rb_ary_entry(signalNames, index);
-	    rb_define_method(klass, StringValuePtr(signal), (VALUE (*) (...)) qt_signal, -1);
-	}
-
-    return new_qt(argc, argv, klass);
-}
-
 static VALUE
 new_qapplication(int argc, VALUE * argv, VALUE klass)
 {
@@ -1694,10 +1674,10 @@ new_qapplication(int argc, VALUE * argv, VALUE klass)
 	rb_ary_unshift(temp, rb_gv_get("$0"));
 	local_argv[0] = INT2NUM(RARRAY(temp)->len);
 	local_argv[1] = temp;
-	result = new_qobject(2, local_argv, klass);
+	result = new_qt(2, local_argv, klass);
 	free(local_argv);
     } else {
-	result = new_qobject(argc, argv, klass);
+	result = new_qt(argc, argv, klass);
     }
 
     rb_gv_set("$qApp", result);
@@ -2198,6 +2178,25 @@ make_metaObject(VALUE /*self*/, VALUE className_value, VALUE parent, VALUE slot_
     return Data_Wrap_Struct(qmetaobject_class, smokeruby_mark, smokeruby_free, o);
 }
 
+static VALUE
+add_metaobject_methods(VALUE self, VALUE klass)
+{
+	rb_define_method(klass, "qt_invoke", (VALUE (*) (...)) qt_invoke, -1);
+	rb_define_method(klass, "qt_emit", (VALUE (*) (...)) qt_invoke, -1);
+	rb_define_method(klass, "metaObject", (VALUE (*) (...)) metaObject, 0);
+	return self;
+}
+
+static VALUE
+add_signal_methods(VALUE self, VALUE klass, VALUE signalNames)
+{
+	for (long index = 0; index < RARRAY(signalNames)->len; index++) {
+		VALUE signal = rb_ary_entry(signalNames, index);
+		rb_define_method(klass, StringValuePtr(signal), (VALUE (*) (...)) qt_signal, -1);
+	}
+	return self;
+}
+
 static VALUE
 dispose(VALUE self)
 {
@@ -2607,7 +2606,7 @@ kde_package_to_class(const char * package, VALUE base_class)
 	} else if (packageName.startsWith("Kontact::")) {
 		klass = rb_define_class_under(kontact_module, package+strlen("Kontact::"), base_class);
 		rb_define_singleton_method(klass, "new", (VALUE (*) (...)) _new_kde, -1);
-	} else if (packageName.startsWith("Ko")) {
+	} else if (packageName.startsWith("Ko") && scope_op.search(packageName) == -1) {
 		klass = rb_define_class_under(koffice_module, package+strlen("Ko"), base_class);
 		rb_define_singleton_method(klass, "new", (VALUE (*) (...)) _new_kde, -1);
 	} else if (packageName.startsWith("Kate::")) {
@@ -2647,15 +2646,12 @@ create_qobject_class(VALUE /*self*/, VALUE package_value)
 		if (strcmp(package, "Qt::Application") == 0) {
 			rb_define_singleton_method(klass, "new", (VALUE (*) (...)) new_qapplication, -1);
 			rb_define_method(klass, "ARGV", (VALUE (*) (...)) qapplication_argv, 0);
-		} else {
-			rb_define_singleton_method(klass, "new", (VALUE (*) (...)) new_qobject, -1);
 		}
 	} else if (QString(package).startsWith("Qext::")) {
 		if (qext_scintilla_module == Qnil) {
 			qext_scintilla_module = rb_define_module("Qext");
 		}
 		klass = rb_define_class_under(qext_scintilla_module, package+strlen("Qext::"), qt_base_class);
-		rb_define_singleton_method(klass, "new", (VALUE (*) (...)) new_qobject, -1);
 	} else {
 		klass = kde_package_to_class(package, qt_base_class);
 	}
@@ -2841,6 +2837,8 @@ Init_qtruby()
     rb_define_module_function(qt_internal_module, "make_QUMethod", (VALUE (*) (...)) make_QUMethod, 2);
     rb_define_module_function(qt_internal_module, "make_QMetaData_tbl", (VALUE (*) (...)) make_QMetaData_tbl, 1);
     rb_define_module_function(qt_internal_module, "make_metaObject", (VALUE (*) (...)) make_metaObject, 6);
+    rb_define_module_function(qt_internal_module, "addMetaObjectMethods", (VALUE (*) (...)) add_metaobject_methods, 1);
+    rb_define_module_function(qt_internal_module, "addSignalMethods", (VALUE (*) (...)) add_signal_methods, 2);
     rb_define_module_function(qt_internal_module, "mapObject", (VALUE (*) (...)) mapObject, 1);
     // isQOjbect => isaQObject
     rb_define_module_function(qt_internal_module, "isQObject", (VALUE (*) (...)) isaQObject, 1);
