@@ -1,4 +1,4 @@
-// eventhandling.cs - qt-csharp Hello World
+// eventhandling.cs - qt-sharp Hello World
 //
 // Author: Adam Treat <manyoso@yahoo.com>
 //
@@ -37,7 +37,7 @@ namespace QtSamples {
 
 		class MyButton : QPushButton {
 
-			public MyButton (QWidget parent) : base ("Hello Qt-CSharp-0.4!", parent)
+			public MyButton (QWidget parent) : base ("Hello Qt-Sharp-0.7!", parent)
 			{
 				// This is the local event handler for mousePressEvents
 				mousePressEvent += new MousePressEvent (pressEvent);
